'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = WorkerMock;

var _structuredClone = require('structured-clone');

var _structuredClone2 = _interopRequireDefault(_structuredClone);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createScope = function createScope(onMessage) {
  var listeners = [];

  return {
    self: {
      postMessage: function postMessage(data) {
        setImmediate(function () {
          return onMessage((0, _structuredClone2.default)(data));
        });
      },
      addEventListener: function addEventListener(name, listener) {
        listeners.push(listener);
      },
      removeEventListener: function removeEventListener(name, listener) {
        var index = listeners.indexOf(listener);

        if (index > -1) {
          listeners.splice(index, 1);
        }
      }
    },
    notify: function notify(data) {
      listeners.forEach(function (listener) {
        return listener({ type: 'message', data: data });
      });
    }
  };
};
/* eslint-env node */

function WorkerMock(callback) {
  var workerScope = createScope(function (data) {
    return clientScope.notify(data);
  });
  var clientScope = createScope(function (data) {
    return workerScope.notify(data);
  });

  callback(workerScope.self);

  return clientScope.self;
}
//# sourceMappingURL=WorkerMock.js.map